@@ -1,4 +1,4 @@
-from yta_general_utils.programming.parameter_validator import PythonValidator
+from yta_general_utils.programming.validator import PythonValidator
 
 import numpy as np
 
